==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/lib/puppet/type/wls_datasource.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_datasource) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a datasource in an WebLogic domain.

    Here is an example on how you should use this:

        # this will use default as wls_setting identifier, no XA properties
        wls_datasource { 'hrDS':
          ensure                           => 'present',
          connectioncreationretryfrequency => '0',
          drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
          extraproperties                  => ['SendStreamAsBlob=true', 'oracle.net.CONNECT_TIMEOUT=10001'],
          fanenabled                       => '0',
          globaltransactionsprotocol       => 'TwoPhaseCommit',
          initialcapacity                  => '2',
          initsql                          => 'None',
          jndinames                        => ['jdbc/hrDS', 'jdbc/hrDS2'],
          maxcapacity                      => '15',
          mincapacity                      => '1',
          rowprefetchenabled               => '0',
          rowprefetchsize                  => '48',
          secondstotrustidlepoolconnection => '10',
          statementcachesize               => '10',
          target                           => ['wlsServer1', 'wlsServer2'],
          targettype                       => ['Server', 'Server'],
          testconnectionsonreserve         => '0',
          testfrequency                    => '120',
          testtablename                    => 'SQL SELECT 1 FROM DUAL',
          url                              => 'jdbc:oracle:thin:@dbagent2.alfa.local:1521/test.oracle.com',
          user                             => 'hr',
          usexa                            => '0',
        }

    In this example you are managing a datasource in the default domain. When you want to
    manage a datasource in a specific domain, you can use:

        # this will use default as wls_setting identifier, no XA properties
        wls_datasource{'mydomain/hrDS':
          ...
          ensure                           => 'present',
          connectioncreationretryfrequency => '0',
          drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
          ...
        }

    Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/jdbc.htm#INTRO215) for more information
    about configuring and managing datasources.

    EOD

    index_condition do |  name, path, wls_config |
      datasource_list = wls_config.get("#{path}/#{name}/JDBCResource/#{name}/JDBCDataSourceParams/#{name}/DataSourceList")
      datasource_list == ''
    end

   on_create do
      Puppet.info "create #{name} "
      create_resource
      #
      # JDBC Datasource requires that you also set the name attribute
      #
      key = "/JDBCSystemResources/#{datasource_name}/JDBCResource/#{datasource_name}/Name"
      wls_config.set(key, datasource_name)
      nil
    end


    bean_type('JDBCSystemResource')

    ensurable
    parameter :domain
    parameter :name
    parameter :datasource_name
    parameter :timeout
    parameter :domain_name

    property :datasource_type
    property :password
    property :target
    property :targettype
    property :jndinames
    property :drivername
    property :url
    property :usexa
    property :user
    property :testtablename
    property :globaltransactionsprotocol
    property :extraproperties
    property :xaproperties
    property :maxcapacity
    property :initialcapacity
    property :fanenabled
    property :onsnodelist
    property :mincapacity
    property :statementcachesize
    property :testconnectionsonreserve
    property :secondstotrustidlepoolconnection
    property :testfrequency
    property :connectioncreationretryfrequency
    property :rowprefetchenabled
    property :rowprefetchsize
    property :initsql
    property :shrinkfrequencyseconds
    property :wrapdatatypes
    extraproperties do
      property :ds_algorithm_type
      property :ds_connection_pool_failover_callback_handler
      property :ds_data_source_list
      property :ds_failover_request_if_busy
      property :ds_jndi_names
      property :ds_keep_conn_after_global_tx
      property :ds_keep_conn_after_local_tx
      property :ds_row_prefetch
      property :ds_row_prefetch_size
      property :ds_scope
      property :ds_stream_chunk_size
      property :xa_end_only_once
      property :xa_keep_logical_conn_open_on_release
      property :xa_keep_xa_conn_till_tx_complete
      property :xa_need_tx_ctx_on_close
      property :xa_new_xa_conn_for_commit
      property :xa_recover_only_once
      property :xa_resource_health_monitoring
      property :xa_retry_duration_seconds
      property :xa_retry_interval_seconds
      property :xa_rollback_local_tx_upon_conn_close
      property :xa_set_transaction_timeout
      property :xa_transaction_timeout
      property :driver_name
      property :driver_password
      property :driver_url
      property :driver_use_password_indirection
      property :driver_use_xa_data_source_interface
      property :ds_global_transactions_protocol
      property :oracle_active_gridlink
      property :oracle_affinity_policy
      property :oracle_connection_initialization_callback
      property :oracle_enable_java_net_fast_path
      property :oracle_fan_enabled
      property :oracle_ons_node_list
      property :oracle_ons_wallet_file
      property :oracle_ons_wallet_password
      property :oracle_optimize_utf8_conversion
      property :oracle_proxy_session
      property :oracle_replay_initiation_timeout
      property :oracle_use_database_credentials
      property :pool_capacity_increment
      property :pool_connection_creation_retry_frequency_seconds
      property :pool_connection_labeling_callback
      property :pool_count_of_refresh_failures_till_disable
      property :pool_credential_mapping_enabled
      property :pool_highest_num_waiters
      property :pool_identity_based_connection_pooling_enabled
      property :pool_initial_capacity
      property :pool_init_sql
      property :pool_profile_harvest_frequency_seconds
      property :pool_statement_cache_type
      property :pool_connection_reserve_timeout_seconds
      property :pool_driver_interceptor
      property :pool_jdbcxa_debug_level
      property :pool_max_capacity
      property :pool_min_capacity
      property :pool_seconds_to_trust_an_idle_pool_connection
      property :pool_shrink_frequency_seconds
      property :pool_statement_timeout
      property :pool_test_frequency_seconds
      property :pool_wrap_jdbc
      property :pool_connection_harvest_max_count
      property :pool_count_of_test_failures_till_flush
      property :pool_fatal_error_codes
      property :pool_ignore_in_use_connections_enabled
      property :pool_inactive_connection_timeout_seconds
      property :pool_login_delay_seconds
      property :pool_pinned_to_thread
      property :pool_test_table_name
      property :pool_wrap_types
      property :compatibility_name
      property :deployment_order
      property :deployment_principal_name
      property :module_type
      property :pool_connection_harvest_trigger_count
      property :pool_profile_type
      property :pool_remove_infected_connections
      property :pool_statement_cache_size
      property :pool_test_connections_on_reserve
      property :source_path
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :ds_proxy_switching_callback
      property :ds_proxy_switching_properties
      property :pool_profile_connection_leak_timeout_seconds
      property :tags
    end

    add_title_attributes(:datasource_name)
  end
end

==> enterprisemodules-wls_config-3.4.0.tar.gz: enterprisemodules-wls_config-3.4.0/lib/puppet/type/wls_datasource.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_datasource) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a datasource in an WebLogic domain.

    Here is an example on how you should use this:

        # this will use default as wls_setting identifier, no XA properties
        wls_datasource { 'hrDS':
          ensure                           => 'present',
          connectioncreationretryfrequency => '0',
          drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
          extraproperties                  => ['SendStreamAsBlob=true', 'oracle.net.CONNECT_TIMEOUT=10001'],
          fanenabled                       => '0',
          globaltransactionsprotocol       => 'TwoPhaseCommit',
          initialcapacity                  => '2',
          initsql                          => 'None',
          jndinames                        => ['jdbc/hrDS', 'jdbc/hrDS2'],
          maxcapacity                      => '15',
          mincapacity                      => 1,
          rowprefetchenabled               => '0',
          rowprefetchsize                  => '48',
          secondstotrustidlepoolconnection => '10',
          statementcachesize               => '10',
          target                           => ['wlsServer1', 'wlsServer2'],
          targettype                       => ['Server', 'Server'],
          testconnectionsonreserve         => '0',
          testfrequency                    => '120',
          testtablename                    => 'SQL SELECT 1 FROM DUAL',
          url                              => 'jdbc:oracle:thin:@dbagent2.alfa.local:1521/test.oracle.com',
          user                             => 'hr',
          usexa                            => '0',
        }

    In this example you are managing a datasource in the default domain. When you want to
    manage a datasource in a specific domain, you can use:

        # this will use default as wls_setting identifier, no XA properties
        wls_datasource{'mydomain/hrDS':
          ...
          ensure                           => 'present',
          connectioncreationretryfrequency => '0',
          drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
          ...
        }

    Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/jdbc.htm#INTRO215) for more information
    about configuring and managing datasources.

    EOD

    index_condition do |  name, path, wls_config |
      datasource_list = wls_config.get("#{path}/#{name}/JDBCResource/#{name}/JDBCDataSourceParams/#{name}/DataSourceList")
      datasource_list == ''
    end

   on_create do
      Puppet.info "create #{name} "
      create_resource
      #
      # JDBC Datasource requires that you also set the name attribute
      #
      key = "/JDBCSystemResources/#{datasource_name}/JDBCResource/#{datasource_name}/Name"
      wls_config.set(key, datasource_name)
      nil
    end


    bean_type('JDBCSystemResource')

    ensurable
    parameter :domain
    parameter :name
    parameter :datasource_name
    parameter :timeout
    parameter :domain_name

    property :datasource_type
    property :password
    property :target
    property :targettype
    property :jndinames
    property :drivername
    property :url
    property :usexa
    property :user
    property :testtablename
    property :globaltransactionsprotocol
    property :extraproperties
    property :xaproperties
    property :maxcapacity
    property :initialcapacity
    property :fanenabled
    property :onsnodelist
    property :mincapacity
    property :statementcachesize
    property :testconnectionsonreserve
    property :secondstotrustidlepoolconnection
    property :testfrequency
    property :connectioncreationretryfrequency
    property :rowprefetchenabled
    property :rowprefetchsize
    property :initsql
    property :shrinkfrequencyseconds
    property :wrapdatatypes
    extraproperties do
      property :ds_algorithm_type
      property :ds_connection_pool_failover_callback_handler
      property :ds_data_source_list
      property :ds_failover_request_if_busy
      property :ds_jndi_names
      property :ds_keep_conn_after_global_tx
      property :ds_keep_conn_after_local_tx
      property :ds_row_prefetch
      property :ds_row_prefetch_size
      property :ds_scope
      property :ds_stream_chunk_size
      property :xa_end_only_once
      property :xa_keep_logical_conn_open_on_release
      property :xa_keep_xa_conn_till_tx_complete
      property :xa_need_tx_ctx_on_close
      property :xa_new_xa_conn_for_commit
      property :xa_recover_only_once
      property :xa_resource_health_monitoring
      property :xa_retry_duration_seconds
      property :xa_retry_interval_seconds
      property :xa_rollback_local_tx_upon_conn_close
      property :xa_set_transaction_timeout
      property :xa_transaction_timeout
      property :driver_name
      property :driver_password
      property :driver_url
      property :driver_use_password_indirection
      property :driver_use_xa_data_source_interface
      property :ds_global_transactions_protocol
      property :oracle_active_gridlink
      property :oracle_affinity_policy
      property :oracle_connection_initialization_callback
      property :oracle_enable_java_net_fast_path
      property :oracle_fan_enabled
      property :oracle_ons_node_list
      property :oracle_ons_wallet_file
      property :oracle_ons_wallet_password
      property :oracle_optimize_utf8_conversion
      property :oracle_proxy_session
      property :oracle_replay_initiation_timeout
      property :oracle_use_database_credentials
      property :pool_capacity_increment
      property :pool_connection_creation_retry_frequency_seconds
      property :pool_connection_labeling_callback
      property :pool_count_of_refresh_failures_till_disable
      property :pool_credential_mapping_enabled
      property :pool_highest_num_waiters
      property :pool_identity_based_connection_pooling_enabled
      property :pool_initial_capacity
      property :pool_init_sql
      property :pool_profile_harvest_frequency_seconds
      property :pool_statement_cache_type
      property :pool_connection_reserve_timeout_seconds
      property :pool_driver_interceptor
      property :pool_jdbcxa_debug_level
      property :pool_max_capacity
      property :pool_min_capacity
      property :pool_seconds_to_trust_an_idle_pool_connection
      property :pool_shrink_frequency_seconds
      property :pool_statement_timeout
      property :pool_test_frequency_seconds
      property :pool_wrap_jdbc
      property :pool_connection_harvest_max_count
      property :pool_count_of_test_failures_till_flush
      property :pool_fatal_error_codes
      property :pool_ignore_in_use_connections_enabled
      property :pool_inactive_connection_timeout_seconds
      property :pool_login_delay_seconds
      property :pool_pinned_to_thread
      property :pool_test_table_name
      property :pool_wrap_types
      property :compatibility_name
      property :deployment_order
      property :deployment_principal_name
      property :module_type
      property :pool_connection_harvest_trigger_count
      property :pool_profile_type
      property :pool_remove_infected_connections
      property :pool_statement_cache_size
      property :pool_test_connections_on_reserve
      property :source_path
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
      property :ds_proxy_switching_callback
      property :ds_proxy_switching_properties
      property :pool_profile_connection_leak_timeout_seconds
      property :tags
    end

    add_title_attributes(:datasource_name)
  end
end
